MODULE icosa_init_mod

CONTAINS

  SUBROUTINE icosa_init
  USE icosa
  USE signature_mod
  USE timeloop_gcm_mod
  USE disvert_mod
  USE etat0_mod
  USE wind_mod
  USE mpipara
  USE omp_para
  USE vertical_interp_mod
  USE trace
  USE output_field_mod
  USE xios_mod
  USE write_field_mod
  USE physics_mod
  USE tracer_mod
  USE restart_mod
  USE etat0_mod
  USE diagflux_mod
  USE profiling_mod
  USE init_grid_param_mod
  IMPLICIT NONE
  
    CALL init_profiling
    CALL init_mpipara
    IF(is_mpi_master) CALL print_signature
    CALL trace_off
    CALL xios_init
    CALL init_earth_const 
    CALL init_grid_param(is_mpi_master)
    CALL init_omp_para(is_mpi_master)
    IF(grid_type == grid_ico) CALL compute_metric
    CALL compute_domain
    CALL init_transfert
    CALL init_writefield
    CALL init_trace

  !$OMP PARALLEL  
    CALL switch_omp_no_distrib_level
    IF(grid_type == grid_ico) CALL compute_geometry
    CALL check_total_area
  
    CALL init_disvert 
    CALL init_vertical_interp
    CALL init_tracer
    
    CALL WriteField("Ai",geom%Ai)
  
    IF (is_mpi_root) CALL write_apbp
    CALL init_time
    CALL init_restart
    CALL init_etat0

    CALL output_field_init
    CALL init_timeloop

  !$OMP END PARALLEL

    CALL init_physics

  !$OMP PARALLEL
  
    CALL init_diagflux
    CALL zero_du_phys
    CALL timeloop
    CALL switch_omp_no_distrib_level
  !$OMP END PARALLEL

    CALL output_field_finalize
    CALL close_files
    CALL close_time_counter
    CALL finalize_mpipara

  CONTAINS
 
    SUBROUTINE check_total_area
    IMPLICIT NONE
    INTEGER :: ind,i,j,ij
    REAL(rstd) :: vect(3,6)
    REAL(rstd) :: centr(3),dist    
    REAL(rstd) :: tot_sum=0

    !$OMP BARRIER
    !$OMP MASTER
    IF(grid_type == grid_ico) THEN
       DO ind=1,ndomain
          CALL swap_dimensions(ind)
          CALL swap_geometry(ind)
          DO j=jj_begin,jj_end
             DO i=ii_begin,ii_end
                ij=(j-1)*iim+i
                IF (domain(ind)%own(i,j)) tot_sum=tot_sum+Ai(ij)
             ENDDO
          ENDDO
       ENDDO
    END IF
    IF (is_mpi_root) PRINT *," Diff surf",1-tot_sum/(4*Pi*radius*radius)
    !$OMP END MASTER
    
    END SUBROUTINE check_total_area
  
  END SUBROUTINE icosa_init

  SUBROUTINE force_recompile_unstructured
    USE timestep_unstructured_mod
    USE transport_unstructured_mod
  END SUBROUTINE force_recompile_unstructured

END MODULE icosa_init_mod
